summaryrefslogtreecommitdiffstats
path: root/lib/libc/posix1e/acl_valid.c
diff options
context:
space:
mode:
authorrwatson <rwatson@FreeBSD.org>2001-03-13 02:31:32 +0000
committerrwatson <rwatson@FreeBSD.org>2001-03-13 02:31:32 +0000
commit8e7df2068e923db9a2e7e1d53eb226709656ddf0 (patch)
treedc59d433275058cb54f02bd6533a3a1f872cfc28 /lib/libc/posix1e/acl_valid.c
parent585c8d185e968e4fe013b63908d569484665df4e (diff)
downloadFreeBSD-src-8e7df2068e923db9a2e7e1d53eb226709656ddf0.zip
FreeBSD-src-8e7df2068e923db9a2e7e1d53eb226709656ddf0.tar.gz
o Update copyright dates.
o Rename internal library functions so that they are prefixed with _posix1e or _POSIX1E, removing them from the application namespace (and potential conflict with other ACL functions elsewhere in the system). Obtained from: TrustedBSD Project
Diffstat (limited to 'lib/libc/posix1e/acl_valid.c')
-rw-r--r--lib/libc/posix1e/acl_valid.c18
1 files changed, 9 insertions, 9 deletions
diff --git a/lib/libc/posix1e/acl_valid.c b/lib/libc/posix1e/acl_valid.c
index efb91ed..8c7ca67 100644
--- a/lib/libc/posix1e/acl_valid.c
+++ b/lib/libc/posix1e/acl_valid.c
@@ -1,5 +1,5 @@
/*-
- * Copyright (c) 1999 Robert N. M. Watson
+ * Copyright (c) 1999, 2000, 20001 Robert N. M. Watson
* All rights reserved.
*
* Redistribution and use in source and binary forms, with or without
@@ -23,7 +23,7 @@
* OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
* SUCH DAMAGE.
*
- * $FreeBSD$
+ * $FreeBSD$
*/
/*
* acl_valid -- POSIX.1e ACL check routine
@@ -40,7 +40,7 @@
* and errno set to EINVAL.
*
* Implemented by calling the acl_check routine in acl_support, which
* requires ordering. We call acl_support's acl_sort to make this
* true. POSIX.1e allows acl_valid() to reorder the ACL as it sees fit.
*
* This call is deprecated, as it doesn't ask whether the ACL is valid
@@ -52,8 +52,8 @@ acl_valid(acl_t acl)
{
int error;
- acl_sort(acl);
- error = acl_check(acl);
+ _posix1e_acl_sort(acl);
+ error = _posix1e_acl_check(acl);
if (error) {
errno = error;
return (-1);
@@ -68,8 +68,8 @@ acl_valid_file_np(const char *pathp, acl_type_t type, acl_t acl)
{
int error;
- if (acl_posix1e(acl, type)) {
- error = acl_sort(acl);
+ if (_posix1e_acl(acl, type)) {
+ error = _posix1e_acl_sort(acl);
if (error) {
errno = error;
return (-1);
@@ -85,8 +85,8 @@ acl_valid_fd_np(int fd, acl_type_t type, acl_t acl)
{
int error;
- if (acl_posix1e(acl, type)) {
- error = acl_sort(acl);
+ if (_posix1e_acl(acl, type)) {
+ error = _posix1e_acl_sort(acl);
if (error) {
errno = error;
return (-1);
@@ -40,7 +40,7 @@
*
* Implemented by calling the acl_check routine in acl_support, which
- * requires ordering. We call acl_support's acl_sort to make this
+ * requires ordering. We call acl_support's _posix1e_acl_sort to make this
* true. POSIX.1e allows acl_valid() to reorder the ACL as it sees fit.
*
OpenPOWER on IntegriCloud